# Gene function and cell surface protein association analysis based on single-cell multiomics data
It is a single-cell multiomics data analysis framework that analyzes the association of gene function and cell surface proteins. 
The python packages, datasets and user-friendly manuals of GFPA are freely available at https://github.com/studentiz/gfpa.

## The GFPA framework works with scanpy and supports the following single-cell multimodal analyses
* Single-cell multi-omics data preprocessing
* Quantification of gene function
* Gene function and protein association mining
* Visualization

## Pip install
```python
pip install gfpa
```
## Datasets
The dataset participating in "Gene function and cell surface protein association analysis based on single-cell multiomics data" can be downloaded at [GFPA data warehouse](http://101.34.64.251:8800/)
